"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteOpenerBrowserServiceImpl = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const rpc_service_1 = require("@opensumi/ide-connection/lib/common/rpc-service");
const opener_1 = require("@opensumi/ide-core-browser/lib/opener");
const preferences_1 = require("@opensumi/ide-core-browser/lib/preferences");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const ide_editor_1 = require("@opensumi/ide-editor");
// 不预置SUPPORT_HOSTS，改为用户注册，默认走openerService来处理这部分逻辑
// const SUPPORT_HOSTS = ['localhost', '0.0.0.0', '127.0.0.1'];
let RemoteOpenerBrowserServiceImpl = class RemoteOpenerBrowserServiceImpl extends rpc_service_1.RPCService {
    constructor() {
        super(...arguments);
        this.supportHosts = new Set();
        this.converter = null;
    }
    registerSupportHosts(hosts) {
        for (const host of hosts) {
            this.supportHosts.add(host);
        }
        return ide_core_common_1.Disposable.create(() => {
            for (const host of hosts) {
                this.supportHosts.delete(host);
            }
        });
    }
    registerConverter(converter) {
        if (this.converter) {
            throw new Error('Only one converter is allowed.');
        }
        this.converter = converter;
        return ide_core_common_1.Disposable.create(() => {
            this.converter = null;
        });
    }
    get isRemoteOpenerEnabled() {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        return this.preferenceService.get('remote.opener.enable', true);
    }
    async $openExternal(type, uri) {
        if (!this.isRemoteOpenerEnabled) {
            return;
        }
        const revivedUri = ide_core_common_1.Uri.revive(uri);
        switch (type) {
            case 'url': {
                const url = new URL(decodeURIComponent(revivedUri.toString()));
                if (this.supportHosts.has(url.hostname)) {
                    if (!this.converter) {
                        throw new Error('Converter is not registered.');
                    }
                    const { port } = url;
                    const hostname = this.converter.convert(port);
                    // Default use https protocol
                    url.protocol = 'https';
                    // remove port
                    url.port = '';
                    url.hostname = hostname;
                }
                this.openerService.open(url.toString());
                break;
            }
            case 'file':
                this.workbenchEditorService.open(ide_core_common_1.URI.parse(revivedUri.toString()), { preview: false, focus: true });
                break;
            default:
                // eslint-disable-next-line no-console
                console.warn(`Unsupported ${type}.`);
                break;
        }
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_editor_1.WorkbenchEditorService),
    tslib_1.__metadata("design:type", ide_editor_1.WorkbenchEditorService)
], RemoteOpenerBrowserServiceImpl.prototype, "workbenchEditorService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.CommandService),
    tslib_1.__metadata("design:type", Object)
], RemoteOpenerBrowserServiceImpl.prototype, "commandService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(preferences_1.PreferenceService),
    tslib_1.__metadata("design:type", Object)
], RemoteOpenerBrowserServiceImpl.prototype, "preferenceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(opener_1.IOpenerService),
    tslib_1.__metadata("design:type", Object)
], RemoteOpenerBrowserServiceImpl.prototype, "openerService", void 0);
RemoteOpenerBrowserServiceImpl = tslib_1.__decorate([
    (0, di_1.Injectable)()
], RemoteOpenerBrowserServiceImpl);
exports.RemoteOpenerBrowserServiceImpl = RemoteOpenerBrowserServiceImpl;
//# sourceMappingURL=remote.opener.service.js.map