"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteOpenerClientImpl = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_node_1 = require("@opensumi/ide-core-node");
// remote opener 强制打开的ClientId的数量限制，在限制之内的话会遍历Map，无视ClientId对应强制打开
// 原因是：避免Terminal Restore这种场景下，环境变量的ClientID和窗口的不一致，导致无法使用RemoteOpen，做一个兜底
const FORCE_OPEN_LIMIT = 4;
let RemoteOpenerClientImpl = class RemoteOpenerClientImpl {
    constructor() {
        this.remoteOpenerServices = new Map();
    }
    setRemoteOpenerServiceInstance(clientId, service) {
        if (this.remoteOpenerServices.has(clientId)) {
            this.logger.error(`Remote opener service instance for client ${clientId} already set.`);
        }
        this.remoteOpenerServices.set(clientId, service);
    }
    removeRemoteOpenerServiceInstance(clientId) {
        this.remoteOpenerServices.delete(clientId);
    }
    async openExternal(args, clientId) {
        const service = this.remoteOpenerServices.get(clientId);
        if (!service) {
            // 没有命中ClientID时兜底强制打开
            if (this.remoteOpenerServices.values.length <= FORCE_OPEN_LIMIT) {
                this.remoteOpenerServices.forEach((service, clientId) => {
                    service.openExternal(Object.assign(Object.assign({}, args), { clientId }));
                });
            }
            this.logger.warn(`Remote opener service instance for client ${clientId} not found.`);
            return;
        }
        service.openExternal(args);
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_node_1.INodeLogger),
    tslib_1.__metadata("design:type", Object)
], RemoteOpenerClientImpl.prototype, "logger", void 0);
RemoteOpenerClientImpl = tslib_1.__decorate([
    (0, di_1.Injectable)()
], RemoteOpenerClientImpl);
exports.RemoteOpenerClientImpl = RemoteOpenerClientImpl;
//# sourceMappingURL=opener.client.js.map